@@ -1,9 +1,12 @@
 # -*- coding: utf-8 -*-
+from .._compat import PY2, string_types
 from email.utils import parseaddr
 import re
-import urlparse
+if PY2:
+    from urlparse import urlsplit, urlunsplit
+else:
+    from urllib.parse import urlsplit, urlunsplit
 
-from ..utils import to_unicode
 from .validator import Validator
 
 
@@ -25,7 +28,7 @@ class Match(Validator):
     message = u'This value doesn\'t seem to be valid.'
 
     def __init__(self, regex, message=None, flags=re.IGNORECASE):
-        if isinstance(regex, basestring):
+        if isinstance(regex, string_types):
             regex = re.compile(regex, flags)
         self.regex = regex
         if message is not None:
@@ -52,9 +55,11 @@ class IsColor(Match):
 
 
 class ValidEmail(Validator):
-    """Validates an email address. Note that this uses a very primitive regular
-    expression and should only be used in instances where you later verify by
-    other means, or wen it doesn't matters very much the email is real.
+    """Validates an email address.
+
+    Note that the purpose of this validator is to alert the user of a typing
+    mistake, so it uses a very permissive regexp. Even if the format is valid,
+    it cannot guarantee that the email is real.
 
     :param message:
         Error message to raise in case of a validation error.
@@ -63,9 +68,7 @@ class ValidEmail(Validator):
     message = u'Enter a valid e-mail address.'
 
     email_rx = re.compile(
-        r'''(^[-!#$%&'*+/=?^_`{}|~0-9A-Z]+(\.[-!#$%&'*+/=?^_`{}|~0-9A-Z]+)*'''  # dot-atom
-        r'''|^"([\001-\010\013\014\016-\037!#-\[\]-\177]|\\[\001-011\013\014\016-\177])*"'''  # quoted-string
-        r''')@(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+[A-Z]{2,6}\.?$''',
+        r'[^@]+@[A-Z0-9][A-Z0-9\-\.]{0,61}\.[A-Z0-9]+\.?$',
         re.IGNORECASE)
 
     def __init__(self, message=None):
@@ -73,24 +76,18 @@ class ValidEmail(Validator):
             self.message = message
 
     def __call__(self, py_value=None, form=None):
-        if not py_value:
+        if not py_value or '@' not in py_value:
             return False
         _, py_value = parseaddr(py_value)
-        if self.email_rx.match(py_value):
-            return True
-        # Common case failed. Try for possible IDN domain-part
         try:
-            if py_value and u'@' in py_value:
-                py_value = self._encode_idna(py_value)
-            return bool(self.email_rx.match(py_value))
+            py_value = self._encode_idna(py_value)
         except UnicodeDecodeError:
-            pass
-        return False
+            return False
+        return bool(self.email_rx.match(py_value))
 
     def _encode_idna(self, py_value):
         parts = py_value.split(u'@')
-        domain_part = parts[-1]
-        parts[-1] = parts[-1].encode('idna')
+        parts[-1] = parts[-1].encode('idna').decode("utf-8", "strict")
         return u'@'.join(parts)
 
 
@@ -109,10 +106,10 @@ class ValidURL(Validator):
 
     """
     message = u'Enter a valid URL.'
-    url_rx = ur'^([a-z]{3,7}:(//)?)?([^/:]+%s|([0-9]{1,3}\.){3}[0-9]{1,3})(:[0-9]+)?(\/.*)?$'
+    url_rx = r'^([a-z]{3,7}:(//)?)?([^/:]+%s|([0-9]{1,3}\.){3}[0-9]{1,3})(:[0-9]+)?(\/.*)?$'
 
     def __init__(self, message=None, require_tld=True):
-        tld_part = ur'\.[a-z]{2,10}' if require_tld else u''
+        tld_part = r'\.[a-z]{2,10}' if require_tld else u''
         self.regex = re.compile(self.url_rx % tld_part, re.IGNORECASE)
         if message is not None:
             self.message = message
@@ -131,6 +128,6 @@ class ValidURL(Validator):
         return False
 
     def _encode_idna(self, py_value):
-        scheme, netloc, path, query, fragment = urlparse.urlsplit(py_value)
+        scheme, netloc, path, query, fragment = urlsplit(py_value)
         netloc = netloc.encode('idna')  # IDN -> ACE
-        return urlparse.urlunsplit((scheme, netloc, path, query, fragment))
+        return urlunsplit((scheme, netloc, path, query, fragment))
